@@ -23,7 +23,7 @@ tour_length.TSP <- function(x, order) {
     n <- n_of_cities(x)
     if(missing(order)) order <- 1:n
 
-    .Call("tour_length_dist", x, order)
+    .Call("tour_length_dist", x, order, PACKAGE="TSP")
 }
 
 tour_length.ATSP <- function(x, order) {
@@ -31,7 +31,7 @@ tour_length.ATSP <- function(x, order) {
     n <- n_of_cities(x)
     if(missing(order)) order <- 1:n
 
-    .Call("tour_length_matrix", x, order)
+    .Call("tour_length_matrix", x, order, PACKAGE="TSP")
 }
 
 ## generic
